@@ -128,7 +128,7 @@ menu_get_panel (GtkWidget *menu)
 	g_return_val_if_fail (menu != NULL, NULL);
 
 	if (GTK_IS_MENU_ITEM (menu))
-		menu = menu->parent;
+		menu = gtk_widget_get_parent (menu);
 
 	g_return_val_if_fail (GTK_IS_MENU (menu), NULL);
 
@@ -137,7 +137,7 @@ menu_get_panel (GtkWidget *menu)
 		if (retval)
 			break;
 
-		menu = gtk_menu_get_attach_widget (GTK_MENU (menu))->parent;
+		menu = gtk_widget_get_parent (gtk_menu_get_attach_widget (GTK_MENU (menu)));
 		if (!GTK_IS_MENU (menu))
 			break;
 	}
@@ -191,7 +191,7 @@ reload_image_menu_items (void)
 		GtkWidget *image = l->data;
 		gboolean   is_mapped;
       
-		is_mapped = GTK_WIDGET_MAPPED (image);
+		is_mapped = gtk_widget_get_mapped (image);
 
 		if (is_mapped)
 			gtk_widget_unmap (image);
@@ -424,8 +424,8 @@ panel_make_menu_icon (GtkIconTheme *icon_theme,
 }
 
 static void
-menu_item_style_set (GtkImage *image,
-		     gpointer  data)
+menu_item_style_updated (GtkImage *image,
+                         gpointer  data)
 {
 	GtkWidget   *widget;
 	GdkPixbuf   *pixbuf;
@@ -445,7 +445,7 @@ menu_item_style_set (GtkImage *image,
 
 	widget = GTK_WIDGET (image);
 
-	is_mapped = GTK_WIDGET_MAPPED (widget);
+	is_mapped = gtk_widget_get_mapped (widget);
 	if (is_mapped)
 		gtk_widget_unmap (widget);
 
@@ -480,8 +480,8 @@ do_icons_to_add (void)
 				GTK_IMAGE (icon_to_add->image),
 				icon_to_add->pixbuf);
 
-			g_signal_connect (icon_to_add->image, "style-set",
-					  G_CALLBACK (menu_item_style_set),
+			g_signal_connect (icon_to_add->image, "style-updated",
+					  G_CALLBACK (menu_item_style_updated),
 					  GINT_TO_POINTER (icon_to_add->icon_size));
 
 			g_object_unref (icon_to_add->pixbuf);
@@ -515,7 +515,7 @@ load_icons_handler_again:
 	icons_to_load = g_list_delete_link (icons_to_load, icons_to_load);
 
 	/* if not visible anymore, just ignore */
-	if ( ! GTK_WIDGET_VISIBLE (icon->pixmap)) {
+	if ( ! gtk_widget_get_visible (icon->pixmap)) {
 		icon_to_load_free (icon);
 		/* we didn't do anything long/hard, so just do this again,
 		 * this is fun, don't go back to main loop */
@@ -814,7 +814,7 @@ static void
 restore_grabs(GtkWidget *w, gpointer data)
 {
 	GtkWidget *menu_item = data;
-	GtkMenu *menu = GTK_MENU(menu_item->parent); 
+	GtkMenu *menu = GTK_MENU (gtk_widget_get_parent (menu_item));
 	GtkWidget *xgrab_shell;
 	GtkWidget *parent;
 
@@ -827,37 +827,42 @@ restore_grabs(GtkWidget *w, gpointer data)
 		GtkWidget *tmp = parent;
 
 		while (tmp) {
-			if (!GTK_WIDGET_MAPPED (tmp)) {
+			if (!gtk_widget_get_mapped (tmp)) {
 				viewable = FALSE;
 				break;
 			}
-			tmp = tmp->parent;
+			tmp = gtk_widget_get_parent (tmp);
 		}
 
 		if (viewable)
 			xgrab_shell = parent;
 
-		parent = GTK_MENU_SHELL (parent)->parent_menu_shell;
+		parent = gtk_menu_shell_get_parent_shell (GTK_MENU_SHELL (parent));
 	}
 
 	/*only grab if this HAD a grab before*/
-	if (xgrab_shell && (GTK_MENU_SHELL (xgrab_shell)->have_xgrab))
+	/* FIXMEgpoo: We need either accessors or a workaround to grab
+	   the focus */
+#if 0
+	if (xgrab_shell && (GTK_MENU_SHELL (xgrab_shell)->GSEAL(have_xgrab)))
           {
-	    if (gdk_pointer_grab (xgrab_shell->window, TRUE,
+	    GdkWindow *window = gtk_widget_get_window (xgrab_shell);
+
+	    if (gdk_pointer_grab (window, TRUE,
 				  GDK_BUTTON_PRESS_MASK |
 				  GDK_BUTTON_RELEASE_MASK |
 				  GDK_ENTER_NOTIFY_MASK |
 				  GDK_LEAVE_NOTIFY_MASK,
 				  NULL, NULL, 0) == 0)
               {
-		if (gdk_keyboard_grab (xgrab_shell->window, TRUE,
+		if (gdk_keyboard_grab (window, TRUE,
 				       GDK_CURRENT_TIME) == 0)
-		  GTK_MENU_SHELL (xgrab_shell)->have_xgrab = TRUE;
+		  GTK_MENU_SHELL (xgrab_shell)->GSEAL(have_xgrab) = TRUE;
 		else
 		  gdk_pointer_ungrab (GDK_CURRENT_TIME);
 	      }
          }
-	
+#endif
 	gtk_grab_add (GTK_WIDGET (menu));
 }
 
@@ -1024,7 +1029,7 @@ drag_end_menu_cb (GtkWidget *widget, GdkDragContext     *context)
 
   /* Find the last viewable ancestor, and make an X grab on it
    */
-  parent = widget->parent;
+  parent = gtk_widget_get_parent (widget);
   xgrab_shell = NULL;
 
   /* FIXME: workaround for a possible gtk+ bug
@@ -1039,40 +1044,67 @@ drag_end_menu_cb (GtkWidget *widget, GdkDragContext     *context)
       
       while (tmp)
 	{
-	  if (!GTK_WIDGET_MAPPED (tmp))
+	  if (!gtk_widget_get_mapped (tmp))
 	    {
 	      viewable = FALSE;
 	      break;
 	    }
-	  tmp = tmp->parent;
+	  tmp = gtk_widget_get_parent (tmp);
 	}
       
       if (viewable)
 	xgrab_shell = parent;
       
-      parent = GTK_MENU_SHELL (parent)->parent_menu_shell;
+      parent = gtk_menu_shell_get_parent_shell (GTK_MENU_SHELL (parent));
     }
   
-  if (xgrab_shell && !GTK_MENU(xgrab_shell)->torn_off)
+  if (xgrab_shell && !gtk_menu_get_tearoff_state (GTK_MENU(xgrab_shell)))
     {
+      gboolean      status;
+      GdkDisplay    *display;
+      GdkDevice     *pointer;
+      GdkDevice     *keyboard;
+      GdkDeviceManager *device_manager;
+      GdkWindow *window = gtk_widget_get_window (xgrab_shell);
       GdkCursor *cursor = gdk_cursor_new (GDK_ARROW);
 
-      if ((gdk_pointer_grab (xgrab_shell->window, TRUE,
-			     GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-			     GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-			     GDK_POINTER_MOTION_MASK,
-			     NULL, cursor, GDK_CURRENT_TIME) == 0))
+      display = gdk_window_get_display (window);
+      device_manager = gdk_display_get_device_manager (display);
+      pointer = gdk_device_manager_get_client_pointer (device_manager);
+      keyboard = gdk_device_get_associated_device (pointer);
+
+      /* FIXMEgpoo: Not sure if report to GDK_OWNERSHIP_WINDOW
+	            or GDK_OWNERSHIP_APPLICATION. Idem for the
+                    keyboard below */
+      status = gdk_device_grab (pointer, window,
+                                GDK_OWNERSHIP_WINDOW, TRUE,
+                                GDK_BUTTON_PRESS_MASK
+                                | GDK_BUTTON_RELEASE_MASK
+                                | GDK_ENTER_NOTIFY_MASK
+                                | GDK_LEAVE_NOTIFY_MASK
+                                | GDK_POINTER_MOTION_MASK,
+                                cursor, GDK_CURRENT_TIME);
+
+      if (!status)
 	{
-	  if (gdk_keyboard_grab (xgrab_shell->window, TRUE,
-				 GDK_CURRENT_TIME) == 0)
-	    GTK_MENU_SHELL (xgrab_shell)->have_xgrab = TRUE;
+	  if (gdk_device_grab (keyboard, window,
+			       GDK_OWNERSHIP_WINDOW, TRUE,
+			       GDK_KEY_PRESS | GDK_KEY_RELEASE,
+			       NULL, GDK_CURRENT_TIME) == GDK_GRAB_SUCCESS)
+	    {
+	    /* FIXMEgpoo: We need either accessors or a workaround to grab
+	       the focus */
+#if 0
+	     GTK_MENU_SHELL (xgrab_shell)->GSEAL(have_xgrab) = TRUE;
+#endif
+	    }
 	  else
 	    {
-	      gdk_pointer_ungrab (GDK_CURRENT_TIME);
+	      gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
 	    }
 	}
 
-      gdk_cursor_unref (cursor);
+      g_object_unref (cursor);
     }
 }
 
@@ -1094,19 +1126,21 @@ drag_data_get_menu_cb (GtkWidget        *widget,
 	g_free (uri);
 
 	gtk_selection_data_set (selection_data,
-				selection_data->target, 8, (guchar *)uri_list,
+				gtk_selection_data_get_target (selection_data), 8, (guchar *)uri_list,
 				strlen (uri_list));
 	g_free (uri_list);
 }
 
 static void
-image_menuitem_size_request (GtkWidget      *menuitem,
-			     GtkRequisition *requisition,
-			     gpointer        data)
+image_menuitem_set_size_request (GtkWidget  *menuitem,
+                                 GtkIconSize icon_size)
 {
-	GtkIconSize icon_size = (GtkIconSize) GPOINTER_TO_INT (data);
-	int         icon_height;
-	int         req_height;
+        GtkStyleContext *context;
+        GtkStateFlags state;
+        GtkBorder padding, border;
+        int border_width;
+	int icon_height;
+	int req_height;
 
 	if (!gtk_icon_size_lookup (icon_size, NULL, &icon_height))
 		return;
@@ -1117,10 +1151,15 @@ image_menuitem_size_request (GtkWidget      *menuitem,
 	 * This is a bit ugly, since we should keep this in sync with what's in
 	 * gtk_menu_item_size_request()
 	 */
+        context = gtk_widget_get_style_context (menuitem);
+        state = gtk_widget_get_state_flags (menuitem);
+        gtk_style_context_get_padding (context, state, &padding);
+        gtk_style_context_get_border (context, state, &border);
+
+        border_width = gtk_container_get_border_width (GTK_CONTAINER (menuitem));
 	req_height = icon_height;
-	req_height += (GTK_CONTAINER (menuitem)->border_width +
-		       menuitem->style->ythickness) * 2;
-	requisition->height = MAX (requisition->height, req_height);
+	req_height += (border_width * 2) + padding.top + padding.bottom + border.top + border.bottom;
+        gtk_widget_set_size_request (menuitem, -1, req_height);
 }
 
 static char *
@@ -1193,9 +1232,7 @@ setup_menuitem (GtkWidget   *menuitem,
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
 					       image);
 	} else if (icon_size != GTK_ICON_SIZE_INVALID)
-		g_signal_connect (menuitem, "size_request",
-				  G_CALLBACK (image_menuitem_size_request),
-				  GINT_TO_POINTER (icon_size));
+                image_menuitem_set_size_request (menuitem, icon_size);
 
 	gtk_widget_show (menuitem);
 }
@@ -1206,7 +1243,7 @@ drag_data_get_string_cb (GtkWidget *widget, GdkDragContext     *context,
 			 guint time, const char *string)
 {
 	gtk_selection_data_set (selection_data,
-				selection_data->target, 8, (guchar *)string,
+				gtk_selection_data_get_target (selection_data), 8, (guchar *)string,
 				strlen(string));
 }
 
@@ -1498,14 +1535,18 @@ create_menuitem (GtkWidget          *menu,
 			alias_directory ? gmenu_tree_directory_get_name (alias_directory) :
 					  gmenu_tree_entry_get_display_name (entry));
 
-	if ((alias_directory &&
-	     gmenu_tree_directory_get_comment (alias_directory)) ||
-	    (!alias_directory &&
-	     gmenu_tree_entry_get_comment (entry)))
+	if (alias_directory &&
+	    gmenu_tree_directory_get_comment (alias_directory))
 		panel_util_set_tooltip_text (menuitem,
-					     alias_directory ?
-						gmenu_tree_directory_get_comment (alias_directory) :
-						gmenu_tree_entry_get_comment (entry));
+					     gmenu_tree_directory_get_comment (alias_directory));
+	else if	(!alias_directory &&
+		 gmenu_tree_entry_get_comment (entry))
+		panel_util_set_tooltip_text (menuitem,
+					     gmenu_tree_entry_get_comment (entry));
+	else if	(!alias_directory &&
+		 gmenu_tree_entry_get_generic_name (entry))
+		panel_util_set_tooltip_text (menuitem,
+					     gmenu_tree_entry_get_generic_name (entry));
 
 	g_signal_connect_after (menuitem, "button_press_event",
 				G_CALLBACK (menuitem_button_press_event), NULL);
@@ -1582,9 +1623,13 @@ handle_gmenu_tree_changed (GMenuTree *tree,
 			   GtkWidget *menu)
 {
 	guint idle_id;
+	GList *list, *l;
 
-	while (GTK_MENU_SHELL (menu)->children)
-                gtk_widget_destroy (GTK_MENU_SHELL (menu)->children->data);
+	/* Remove existing items */
+	list = gtk_container_get_children (GTK_CONTAINER (menu));
+	for (l = list; l; l = l->next)
+		gtk_widget_destroy (l->data);
+	g_list_free (list);
 
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-tree-directory",
@@ -1676,11 +1721,14 @@ static GtkWidget *
 populate_menu_from_directory (GtkWidget          *menu,
 			      GMenuTreeDirectory *directory)
 {	
+	GList    *children;
 	GSList   *l;
 	GSList   *items;
 	gboolean  add_separator;
 
-	add_separator = (GTK_MENU_SHELL (menu)->children != NULL);
+	children = gtk_container_get_children (GTK_CONTAINER (menu));
+	add_separator = (children != NULL);
+	g_list_free (children);
 
 	items = gmenu_tree_directory_get_contents (directory);
 
@@ -1854,8 +1902,7 @@ panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 	gtk_icon_size_lookup (icon_size, NULL, &icon_height);
 
 	image = gtk_image_new ();
-	image->requisition.width  = icon_height;
-	image->requisition.height = icon_height;
+	gtk_widget_set_size_request (image, icon_height, icon_height);
 
 	/* this takes over the floating ref */
 	icon->pixmap = g_object_ref_sink (G_OBJECT (image));
@@ -1894,22 +1941,21 @@ panel_menu_key_press_handler (GtkWidget   *widget,
 			      GdkEventKey *event)
 {
 	gboolean retval = FALSE;
+	GtkWidget *active_menu_item = NULL;
 
-	if ((event->keyval == GDK_Menu) ||
-	    (event->keyval == GDK_F10 &&
+	if ((event->keyval == GDK_KEY_Menu) ||
+	    (event->keyval == GDK_KEY_F10 &&
 	    (event->state & gtk_accelerator_get_default_mod_mask ()) == GDK_SHIFT_MASK)) {
 		GtkMenuShell *menu_shell = GTK_MENU_SHELL (widget);
 
-		if (menu_shell->active_menu_item &&
-		    GTK_MENU_ITEM (menu_shell->active_menu_item)->submenu == NULL) {
+		active_menu_item = gtk_menu_shell_get_selected_item (menu_shell);
+		if (active_menu_item && gtk_menu_item_get_submenu (GTK_MENU_ITEM (active_menu_item)) == NULL) {
 			GdkEventButton bevent;
 
 			bevent.button = 3;
 			bevent.time = GDK_CURRENT_TIME;
-			retval = show_item_menu (menu_shell->active_menu_item,
-						 &bevent);
+			retval = show_item_menu (active_menu_item, &bevent);
 		}
-		
 	}
 	return retval;
 }
